You are viewing a plain text version of this content. The canonical link for it is here.
Posted to scm@geronimo.apache.org by ha...@apache.org on 2011/05/25 10:16:31 UTC

svn commit: r1127422 [7/7] - in /geronimo/devtools/eclipse-plugin/trunk/plugins: org.apache.geronimo.j2ee.v11.jaxbmodel/ org.apache.geronimo.j2ee.v11.jaxbmodel/src/main/java/org/apache/geronimo/j2ee/jaxbmodel/ org.apache.geronimo.j2ee.v11.jaxbmodel/src...

Modified: geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.core/src/main/java/org/apache/geronimo/st/v30/core/operations/GeronimoServerPluginManager.java
URL: http://svn.apache.org/viewvc/geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.core/src/main/java/org/apache/geronimo/st/v30/core/operations/GeronimoServerPluginManager.java?rev=1127422&r1=1127421&r2=1127422&view=diff
==============================================================================
--- geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.core/src/main/java/org/apache/geronimo/st/v30/core/operations/GeronimoServerPluginManager.java (original)
+++ geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.core/src/main/java/org/apache/geronimo/st/v30/core/operations/GeronimoServerPluginManager.java Wed May 25 08:16:27 2011
@@ -52,6 +52,7 @@ import org.apache.geronimo.kernel.config
 import org.apache.geronimo.kernel.repository.Artifact;
 import org.apache.geronimo.kernel.repository.Dependency;
 import org.apache.geronimo.kernel.repository.ImportType;
+import org.apache.geronimo.st.v30.core.Activator;
 import org.apache.geronimo.st.v30.core.CommonMessages;
 import org.apache.geronimo.st.v30.core.GeronimoConnectionFactory;
 import org.apache.geronimo.st.v30.core.GeronimoServerBehaviourDelegate;
@@ -99,9 +100,9 @@ public class GeronimoServerPluginManager
         } catch (Exception e) {
             e.printStackTrace();
             Trace.trace(Trace.WARNING, "Kernel connection failed. "
-                + e.getMessage());
+                + e.getMessage(), Activator.logOperations);
         }
-        Trace.tracePoint("Constructor", "GeronimoServerPluginManager");
+        Trace.tracePoint("Constructor", Activator.traceOperations, "GeronimoServerPluginManager");
     }
     
     private PluginInstaller getPluginInstaller() {
@@ -113,7 +114,7 @@ public class GeronimoServerPluginManager
     }
     
     public List<String> getPluginList () {
-        Trace.tracePoint("Entry", "GeronimoServerPluginManager.getPluginList");
+        Trace.tracePoint("Entry", Activator.traceOperations, "GeronimoServerPluginManager.getPluginList");
 
         String name;
         boolean added;
@@ -141,14 +142,14 @@ public class GeronimoServerPluginManager
             }
         }
 
-        Trace.tracePoint("Exit", "GeronimoServerPluginManager.getPluginList", pluginList);
+        Trace.tracePoint("Exit", Activator.traceOperations, "GeronimoServerPluginManager.getPluginList", pluginList);
         return pluginList;
     }
 
     // mimics org.apache.geronimo.console.car.AssemblyViewHandler.actionAfterView
     public void assembleServer (String group, String artifact, String version,
                         String format, String relativeServerPath, int[] selected) {
-        Trace.tracePoint("Entry", "GeronimoServerPluginManager.assembleServer",
+        Trace.tracePoint("Entry", Activator.traceOperations, "GeronimoServerPluginManager.assembleServer",
                 group, artifact, version, format);
 
         PluginListType selectedPlugins = new PluginListType();
@@ -175,12 +176,12 @@ public class GeronimoServerPluginManager
         catch (Exception e) {
             e.printStackTrace();
         }
-        Trace.tracePoint("Exit", "GeronimoServerPluginManager.assembleServer");
+        Trace.tracePoint("Exit", Activator.traceOperations, "GeronimoServerPluginManager.assembleServer");
     }
 
     // mimics org.apache.geronimo.console.util.KernelManagementHelper.getConfigurations()
     public List<String> getConfigurationList () {
-        Trace.tracePoint("Entry", "GeronimoServerPluginManager.getConfigurationList");
+        Trace.tracePoint("Entry", Activator.traceOperations, "GeronimoServerPluginManager.getConfigurationList");
 
         ConfigurationManager mgr = getConfigurationManager();
         List<AbstractName> stores = mgr.listStores();
@@ -200,7 +201,7 @@ public class GeronimoServerPluginManager
         }
         Collections.sort(results);
 
-        Trace.tracePoint("Entry", "GeronimoServerPluginManager.getConfigurationList", results);
+        Trace.tracePoint("Entry", Activator.traceOperations, "GeronimoServerPluginManager.getConfigurationList", results);
         return results;
     }
 
@@ -215,7 +216,7 @@ public class GeronimoServerPluginManager
     // mimics org.apache.geronimo.system.plugin.PluginInstallerGBean.updatePluginMetadata
     // but puts the metadata in our local directory
     public void savePluginXML (String configId, PluginType metadata) {
-        Trace.tracePoint("Entry", "GeronimoServerPluginManager.savePluginXML", configId, metadata);
+        Trace.tracePoint("Entry", Activator.traceOperations, "GeronimoServerPluginManager.savePluginXML", configId, metadata);
 
         Artifact artifact = Artifact.create(configId);
         File dir = new File (getArtifactLocation(artifact));
@@ -255,12 +256,12 @@ public class GeronimoServerPluginManager
                 input.close();
                 if (!artifactFile.delete()) {
                     String message = CommonMessages.bind(CommonMessages.errorDeletePlugin, artifactFile.getAbsolutePath());
-                    Trace.tracePoint("Throw", "GeronimoServerPluginManager.savePluginXML", message);
+                    Trace.tracePoint("Throw", Activator.traceOperations, "GeronimoServerPluginManager.savePluginXML", message);
                     throw new Exception(message);
                 }
                 if (!temp.renameTo(artifactFile)) {
                     String message = CommonMessages.bind(CommonMessages.errorMovePlugin, temp.getAbsolutePath(), artifactFile.getAbsolutePath());
-                    Trace.tracePoint("Throw", "GeronimoServerPluginManager.savePluginXML", message);
+                    Trace.tracePoint("Throw", Activator.traceOperations, "GeronimoServerPluginManager.savePluginXML", message);
                     throw new Exception(message);
                 }
             } catch (Exception e) {
@@ -270,7 +271,7 @@ public class GeronimoServerPluginManager
             File meta = new File(addFilename(dir.getAbsolutePath(), artifact), "META-INF");
             if (!meta.isDirectory() || !meta.canRead()) {
                 String message = CommonMessages.bind(CommonMessages.badPlugin, artifact);
-                Trace.tracePoint("Throw", "GeronimoServerPluginManager.savePluginXML", message);
+                Trace.tracePoint("Throw", Activator.traceOperations, "GeronimoServerPluginManager.savePluginXML", message);
                 throw new IllegalArgumentException(message);
             }
             File xml = new File(meta, "geronimo-plugin.xml");
@@ -279,7 +280,7 @@ public class GeronimoServerPluginManager
                 if (!xml.isFile()) {
                     if (!xml.createNewFile()) {
                         String message = CommonMessages.bind(CommonMessages.errorCreateMetadata, artifact);
-                        Trace.tracePoint("Throw", "GeronimoServerPluginManager.savePluginXML", message);
+                        Trace.tracePoint("Throw", Activator.traceOperations, "GeronimoServerPluginManager.savePluginXML", message);
                         throw new RuntimeException(message);
                     }
                 }
@@ -298,12 +299,12 @@ public class GeronimoServerPluginManager
             }
         }
 
-        Trace.tracePoint("Exit", "GeronimoServerPluginManager.savePluginXML");
+        Trace.tracePoint("Exit", Activator.traceOperations, "GeronimoServerPluginManager.savePluginXML");
     }
 
     // mimics org.apache.geronimo.system.configuration.RepositoryConfigurationStore.exportConfiguration
     public void exportCAR (String localRepoDir, String configId) throws Exception {
-        Trace.tracePoint("Entry", "GeronimoServerPluginManager.exportCAR", localRepoDir, configId);
+        Trace.tracePoint("Entry", Activator.traceOperations, "GeronimoServerPluginManager.exportCAR", localRepoDir, configId);
 
         Artifact artifact = Artifact.create(configId);
         String filename = createDirectoryStructure (localRepoDir, artifact);
@@ -312,11 +313,11 @@ public class GeronimoServerPluginManager
         File serverArtifact = new File(getArtifactLocation (artifact));
         writeToDirectory(serverArtifact, outputDir);
 
-        Trace.tracePoint("Exit", "GeronimoServerPluginManager.exportCAR");
+        Trace.tracePoint("Exit", Activator.traceOperations, "GeronimoServerPluginManager.exportCAR");
     }
 
     private void writeToDirectory(File inputDir, File outputDir) throws Exception {
-        Trace.tracePoint("Entry", "GeronimoServerPluginManager.writeToZip", inputDir);
+        Trace.tracePoint("Entry", Activator.traceOperations, "GeronimoServerPluginManager.writeToZip", inputDir);
 
         outputDir.mkdirs();
         File[] all = inputDir.listFiles();
@@ -342,11 +343,11 @@ public class GeronimoServerPluginManager
                 }
             }
         }
-        Trace.tracePoint("Exit", "GeronimoServerPluginManager.writeToZip");
+        Trace.tracePoint("Exit", Activator.traceOperations, "GeronimoServerPluginManager.writeToZip");
     }
 
     public void updatePluginList (String localRepoDir, PluginType metadata) throws Exception {
-        Trace.tracePoint("Entry", "GeronimoServerPluginManager.updatePluginList", localRepoDir, metadata);
+        Trace.tracePoint("Entry", Activator.traceOperations, "GeronimoServerPluginManager.updatePluginList", localRepoDir, metadata);
 
         PluginListType pluginList = readPluginList(localRepoDir);
         File listFile = new File (localRepoDir, "geronimo-plugins.xml");
@@ -381,11 +382,11 @@ public class GeronimoServerPluginManager
                 }
             }
         }
-        Trace.tracePoint("Exit", "GeronimoServerPluginManager.updatePluginList");
+        Trace.tracePoint("Exit", Activator.traceOperations, "GeronimoServerPluginManager.updatePluginList");
     }
 
     public PluginListType readPluginList (String localRepoDir) {
-        Trace.tracePoint("Entry", "GeronimoServerPluginManager.readPluginList", localRepoDir);
+        Trace.tracePoint("Entry", Activator.traceOperations, "GeronimoServerPluginManager.readPluginList", localRepoDir);
 
         PluginListType pluginList = null;
         File listFile = new File (localRepoDir, "geronimo-plugins.xml");
@@ -409,7 +410,7 @@ public class GeronimoServerPluginManager
             pluginList = factory.createPluginListType();
         }
 
-        Trace.tracePoint("Exit", "GeronimoServerPluginManager.readPluginList", pluginList);
+        Trace.tracePoint("Exit", Activator.traceOperations, "GeronimoServerPluginManager.readPluginList", pluginList);
         return pluginList;
     }
 
@@ -488,14 +489,14 @@ public class GeronimoServerPluginManager
     }
 
     private ConfigurationManager getConfigurationManager () {
-        Trace.tracePoint("Entry", "GeronimoServerPluginManager.getConfigurationManager");
+        Trace.tracePoint("Entry", Activator.traceOperations, "GeronimoServerPluginManager.getConfigurationManager");
 
         if (kernel != null) {
-            Trace.tracePoint("Exit", "GeronimoServerPluginManager.getConfigurationManager");
+            Trace.tracePoint("Exit", Activator.traceOperations, "GeronimoServerPluginManager.getConfigurationManager");
             return ConfigurationUtil.getEditableConfigurationManager(kernel);
         }
 
-        Trace.tracePoint("Exit", "GeronimoServerPluginManager.getConfigurationManager returns null");
+        Trace.tracePoint("Exit", Activator.traceOperations, "GeronimoServerPluginManager.getConfigurationManager returns null");
         return null;
     }
 
@@ -550,7 +551,7 @@ public class GeronimoServerPluginManager
     }
 
     public boolean validatePlugin (PluginType plugin) {
-        Trace.tracePoint("Entry", "GeronimoServerPluginManager.validatePlugin", plugin);
+        Trace.tracePoint("Entry", Activator.traceOperations, "GeronimoServerPluginManager.validatePlugin", plugin);
         boolean valid = true;
         try {
             pluginInstaller.validatePlugin(plugin);
@@ -565,7 +566,7 @@ public class GeronimoServerPluginManager
     // mimics org.apache.geronimo.system.plugin.PluginInstallerGbean.install
     // but uses our local directory to get the plugins
     public ArrayList<String> installPlugins (String localRepoDir, List<PluginType> pluginList) {
-        Trace.tracePoint("Entry", "GeronimoServerPluginManager.installPlugins", localRepoDir, pluginList);
+        Trace.tracePoint("Entry", Activator.traceOperations, "GeronimoServerPluginManager.installPlugins", localRepoDir, pluginList);
         ArrayList<String> eventLog = new ArrayList<String>();
 
         //List<Artifact> downloadedArtifacts = new ArrayList<Artifact>();
@@ -637,13 +638,13 @@ public class GeronimoServerPluginManager
             e.printStackTrace();
         }
 
-        Trace.tracePoint("Exit", "GeronimoServerPluginManager.installPlugins", eventLog.toString());
+        Trace.tracePoint("Exit", Activator.traceOperations, "GeronimoServerPluginManager.installPlugins", eventLog.toString());
         return eventLog;
     }
 
     // mimics org.apache.geronimo.system.plugin.PluginInstallerGbean.verifyPrerequisistes
     private void verifyPrerequisites(PluginType plugin) throws Exception {
-        Trace.tracePoint("Exit", "GeronimoServerPluginManager.verifyPrerequisites", plugin);
+        Trace.tracePoint("Exit", Activator.traceOperations, "GeronimoServerPluginManager.verifyPrerequisites", plugin);
         List<Dependency> missingPrereqs = getMissingPrerequisites(plugin);
         if (!missingPrereqs.isEmpty()) {
             PluginArtifactType metadata = plugin.getPluginArtifact().get(0);
@@ -658,20 +659,20 @@ public class GeronimoServerPluginManager
                 }
             }
             buf.append(CommonMessages.installed);
-            Trace.tracePoint("Throw", "GeronimoServerPluginManager.verifyPrerequisites", buf.toString());
+            Trace.tracePoint("Throw", Activator.traceOperations, "GeronimoServerPluginManager.verifyPrerequisites", buf.toString());
             throw new Exception(buf.toString());
         }
 
-        Trace.tracePoint("Exit", "GeronimoServerPluginManager.verifyPrerequisites");
+        Trace.tracePoint("Exit", Activator.traceOperations, "GeronimoServerPluginManager.verifyPrerequisites");
     }
 
     // mimics org.apache.geronimo.system.plugin.PluginInstallerGbean.getMissingPrerequisistes
     private List<Dependency> getMissingPrerequisites(PluginType plugin) {
-        Trace.tracePoint("Entry", "GeronimoServerPluginManager.getMissingPrerequisites", plugin);
+        Trace.tracePoint("Entry", Activator.traceOperations, "GeronimoServerPluginManager.getMissingPrerequisites", plugin);
 
         if (plugin.getPluginArtifact().size() != 1) {
             String message = CommonMessages.bind(CommonMessages.configSizeMismatch, plugin.getPluginArtifact().size());
-            Trace.tracePoint("Throw", "GeronimoServerPluginManager.getMissingPrerequisites", message);
+            Trace.tracePoint("Throw", Activator.traceOperations, "GeronimoServerPluginManager.getMissingPrerequisites", message);
             throw new IllegalArgumentException(message);
         }
 
@@ -686,18 +687,18 @@ public class GeronimoServerPluginManager
                     missingPrereqs.add(new Dependency(artifact, ImportType.ALL));
                 }
             } catch (Exception e) {
-                Trace.tracePoint("Throw", "GeronimoServerPluginManager.getMissingPrerequisites", CommonMessages.noDefaultServer);
+                Trace.tracePoint("Throw", Activator.traceOperations, "GeronimoServerPluginManager.getMissingPrerequisites", CommonMessages.noDefaultServer);
                 throw new RuntimeException(CommonMessages.noDefaultServer);
             }
         }
 
-        Trace.tracePoint("Exit", "GeronimoServerPluginManager.getMissingPrerequisites", missingPrereqs);
+        Trace.tracePoint("Exit", Activator.traceOperations, "GeronimoServerPluginManager.getMissingPrerequisites", missingPrereqs);
         return missingPrereqs;
     }
     
     //Extract the car file
     private void writeToRepository(File inputDir, File outputDir) throws Exception {
-        Trace.tracePoint("Entry", "GeronimoServerPluginManager.writeToRepository", inputDir,outputDir);
+        Trace.tracePoint("Entry", Activator.traceOperations, "GeronimoServerPluginManager.writeToRepository", inputDir,outputDir);
 
         outputDir.mkdirs();
         File[] all = inputDir.listFiles();
@@ -757,6 +758,6 @@ public class GeronimoServerPluginManager
                 }
             }
         }
-        Trace.tracePoint("Exit", "GeronimoServerPluginManager.writeToRepository");
+        Trace.tracePoint("Exit", Activator.traceOperations, "GeronimoServerPluginManager.writeToRepository");
     }
 }

Modified: geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.core/src/main/java/org/apache/geronimo/st/v30/core/operations/ImportDeploymentPlanOperation.java
URL: http://svn.apache.org/viewvc/geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.core/src/main/java/org/apache/geronimo/st/v30/core/operations/ImportDeploymentPlanOperation.java?rev=1127422&r1=1127421&r2=1127422&view=diff
==============================================================================
--- geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.core/src/main/java/org/apache/geronimo/st/v30/core/operations/ImportDeploymentPlanOperation.java (original)
+++ geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.core/src/main/java/org/apache/geronimo/st/v30/core/operations/ImportDeploymentPlanOperation.java Wed May 25 08:16:27 2011
@@ -16,6 +16,7 @@
  */
 package org.apache.geronimo.st.v30.core.operations;
 
+import org.apache.geronimo.st.v30.core.Activator;
 import org.apache.geronimo.st.v30.core.GeronimoUtils;
 import org.apache.geronimo.st.v30.core.internal.Trace;
 import org.apache.geronimo.st.v30.core.jaxb.ConversionHelper;
@@ -41,7 +42,7 @@ public class ImportDeploymentPlanOperati
      */
     public ImportDeploymentPlanOperation() {
         super();
-        Trace.tracePoint("Constructor", "ImportDeploymentPlanOperation");
+        Trace.tracePoint("Constructor", Activator.traceOperations, "ImportDeploymentPlanOperation");
     }
 
     /**
@@ -49,7 +50,7 @@ public class ImportDeploymentPlanOperati
      */
     public ImportDeploymentPlanOperation(IDataModel model) {
         super(model);
-        Trace.tracePoint("Constructor", "ImportDeploymentPlanOperation", model);
+        Trace.tracePoint("Constructor", Activator.traceOperations, "ImportDeploymentPlanOperation", model);
     }
 
     /*
@@ -59,7 +60,7 @@ public class ImportDeploymentPlanOperati
      *      org.eclipse.core.runtime.IAdaptable)
      */
     public IStatus execute(IProgressMonitor monitor, IAdaptable info) throws ExecutionException {
-        Trace.tracePoint("Entry", "ImportDeploymentPlanOperation.execute", monitor, info);
+        Trace.tracePoint("Entry", Activator.traceOperations, "ImportDeploymentPlanOperation.execute", monitor, info);
 
         if (!isGeronimoRuntimeTarget())
             return Status.OK_STATUS;
@@ -95,7 +96,7 @@ public class ImportDeploymentPlanOperati
             throw new ExecutionException("ImportDeploymentPlanOperation.execute(): Error converting plan: " + planFile.getFullPath() );
         }
 
-        Trace.tracePoint("Exit ", "ImportDeploymentPlanOperation.execute", Status.OK_STATUS);
+        Trace.tracePoint("Exit ", Activator.traceOperations, "ImportDeploymentPlanOperation.execute", Status.OK_STATUS);
         return Status.OK_STATUS;
     }
 }

Modified: geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.core/src/main/java/org/apache/geronimo/st/v30/core/operations/SharedLibEntryCreationOperation.java
URL: http://svn.apache.org/viewvc/geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.core/src/main/java/org/apache/geronimo/st/v30/core/operations/SharedLibEntryCreationOperation.java?rev=1127422&r1=1127421&r2=1127422&view=diff
==============================================================================
--- geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.core/src/main/java/org/apache/geronimo/st/v30/core/operations/SharedLibEntryCreationOperation.java (original)
+++ geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.core/src/main/java/org/apache/geronimo/st/v30/core/operations/SharedLibEntryCreationOperation.java Wed May 25 08:16:27 2011
@@ -98,7 +98,7 @@ public class SharedLibEntryCreationOpera
      *      org.eclipse.core.runtime.IAdaptable)
      */
     public IStatus execute(IProgressMonitor monitor, IAdaptable info) throws ExecutionException {
-        Trace.trace(Trace.INFO, ">> SharedLibEntryCreationOperation.execute()");
+        Trace.trace(Trace.INFO, ">> SharedLibEntryCreationOperation.execute()", Activator.traceOperations);
         
         this.monitor = ProgressUtil.getMonitorFor(monitor);
         this.monitor.beginTask("Processing in-place shared libraries.", 100);
@@ -140,7 +140,7 @@ public class SharedLibEntryCreationOpera
                     if (regenerate(dummyJarFile, entries)) {
                         TEMP_LOCATION.toFile().mkdirs();
                         File temp = TEMP_LOCATION.append(project.getName() + ".eclipse.jar").toFile();
-                        Trace.trace(Trace.INFO, "Updating external sharedlib entries for " + module.getName());
+                        Trace.trace(Trace.INFO, "Updating external sharedlib entries for " + module.getName(), Activator.traceOperations);
                         if(temp.exists())
                             delete(temp);
                         Manifest manifest = new Manifest();
@@ -159,16 +159,16 @@ public class SharedLibEntryCreationOpera
             
         }catch (CoreException e){
             IStatus status = e.getStatus();
-            Trace.trace(Trace.SEVERE, status.getMessage(), e);
+            Trace.trace(Trace.ERROR, status.getMessage(), e, Activator.logOperations);
             throw new ExecutionException(status.getMessage(), e);
         }catch (Exception e) {
-            Trace.trace(Trace.SEVERE, "Failure in updating shared library.", e);
+            Trace.trace(Trace.ERROR, "Failure in updating shared library.", e, Activator.logOperations);
             throw new ExecutionException("Failure in updating shared library", e);
         } finally {
             monitor.done();
         }
         
-        Trace.trace(Trace.INFO, "<< SharedLibEntryCreationOperation.execute()");
+        Trace.trace(Trace.INFO, "<< SharedLibEntryCreationOperation.execute()", Activator.traceOperations);
         return Status.OK_STATUS;
     }
     
@@ -206,7 +206,7 @@ public class SharedLibEntryCreationOpera
         } catch (Exception e) {
             throw e;
         }
-        Trace.trace(Trace.INFO, "Created " + dest.getAbsolutePath());
+        Trace.trace(Trace.INFO, "Created " + dest.getAbsolutePath(), Activator.traceOperations);
     }
 
     private String getSharedLibPath() throws Exception {
@@ -225,7 +225,7 @@ public class SharedLibEntryCreationOpera
     }
     
     private HashSet processModule(IModule module) throws Exception {
-        Trace.trace(Trace.INFO, "SharedLibEntryCreationOperation.process() " + module.getName());
+        Trace.trace(Trace.INFO, "SharedLibEntryCreationOperation.process() " + module.getName(), Activator.traceOperations);
 
         IProject project = module.getProject();
         // filter the cp entries needed to be added to the dummy shared lib
@@ -257,9 +257,9 @@ public class SharedLibEntryCreationOpera
 
     private void delete(File dummyJarFile) throws CoreException {
         if(dummyJarFile.delete()) {
-            Trace.trace(Trace.INFO, dummyJarFile.getAbsolutePath() + " deleted sucessfully.");
+            Trace.trace(Trace.INFO, dummyJarFile.getAbsolutePath() + " deleted sucessfully.", Activator.traceOperations);
         } else {
-            Trace.trace(Trace.SEVERE, "Failed to delete " + dummyJarFile.getAbsolutePath(), null);
+            Trace.trace(Trace.ERROR, "Failed to delete " + dummyJarFile.getAbsolutePath(), null, Activator.logOperations);
             throw new CoreException(new Status(IStatus.ERROR,Activator.PLUGIN_ID,"Failed to delete " + dummyJarFile.getAbsolutePath(),null));
         }
     }
@@ -321,12 +321,12 @@ public class SharedLibEntryCreationOpera
             try {
                 String url = f.toURL().toExternalForm();
                 if (!entries.contains(url)) {
-                    Trace.trace(Trace.INFO, "Adding " + url);
+                    Trace.trace(Trace.INFO, "Adding " + url, Activator.traceOperations);
                     monitor.subTask("Linking " + url + " to shared lib.");
                     entries.add(url);
                 }
             } catch (MalformedURLException e1) {
-                Trace.trace(Trace.INFO, "Failed to add " + path);
+                Trace.trace(Trace.INFO, "Failed to add " + path, Activator.traceOperations);
                 e1.printStackTrace();
             }
         }
@@ -434,6 +434,6 @@ public class SharedLibEntryCreationOpera
         DeploymentStatus status = po.getDeploymentStatus();
         String command = status.getCommand().toString();
         String state = status.getState().toString();
-        Trace.trace(Trace.INFO, "SharedLib " + " " + command + " " + state);
+        Trace.trace(Trace.INFO, "SharedLib " + " " + command + " " + state, Activator.traceOperations);
     }
 }

Modified: geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.core/src/main/java/org/apache/geronimo/st/v30/core/osgi/AriesHelper.java
URL: http://svn.apache.org/viewvc/geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.core/src/main/java/org/apache/geronimo/st/v30/core/osgi/AriesHelper.java?rev=1127422&r1=1127421&r2=1127422&view=diff
==============================================================================
--- geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.core/src/main/java/org/apache/geronimo/st/v30/core/osgi/AriesHelper.java (original)
+++ geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.core/src/main/java/org/apache/geronimo/st/v30/core/osgi/AriesHelper.java Wed May 25 08:16:27 2011
@@ -16,6 +16,7 @@
  */
 package org.apache.geronimo.st.v30.core.osgi;
 
+import org.apache.geronimo.st.v30.core.Activator;
 import org.apache.geronimo.st.v30.core.internal.Trace;
 import org.eclipse.core.runtime.Platform;
 import org.osgi.framework.Bundle;
@@ -38,7 +39,7 @@ public final class AriesHelper {
      * @return true or false
      */
     public static boolean isAriesInstalled() {
-        Trace.tracePoint("Entry", "AriesHelper.isAriesInstalled");
+        Trace.tracePoint("Entry", Activator.traceOsgi, "AriesHelper.isAriesInstalled");
 
         Bundle ariesCore = Platform.getBundle("com.ibm.etools.aries.core");
         Bundle ariesUI   = Platform.getBundle("com.ibm.etools.aries.ui");

Modified: geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/.options
URL: http://svn.apache.org/viewvc/geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/.options?rev=1127422&r1=1127421&r2=1127422&view=diff
==============================================================================
--- geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/.options (original)
+++ geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/.options Wed May 25 08:16:27 2011
@@ -1 +1,25 @@
-org.apache.geronimo.st.v30.ui/debug=true
\ No newline at end of file
+org.apache.geronimo.st.v30.v30.ui/debug=true
+
+org.apache.geronimo.st.v30.ui/console=true
+
+org.apache.geronimo.st.v30.ui/log/ui=true
+org.apache.geronimo.st.v30.ui/log/actions=true
+org.apache.geronimo.st.v30.ui/log/commands=true
+org.apache.geronimo.st.v30.ui/log/internal=true
+org.apache.geronimo.st.v30.ui/log/wizards=true
+org.apache.geronimo.st.v30.ui/log/editors=true
+org.apache.geronimo.st.v30.ui/log/pages=true
+org.apache.geronimo.st.v30.ui/log/sections=true
+org.apache.geronimo.st.v30.ui/log/blueprint=true
+org.apache.geronimo.st.v30.ui/log/handlers=true
+
+org.apache.geronimo.st.v30.ui/trace/ui=false
+org.apache.geronimo.st.v30.ui/trace/actions=false
+org.apache.geronimo.st.v30.ui/trace/commands=false
+org.apache.geronimo.st.v30.ui/trace/internal=false
+org.apache.geronimo.st.v30.ui/trace/wizards=false
+org.apache.geronimo.st.v30.ui/trace/editors=false
+org.apache.geronimo.st.v30.ui/trace/pages=false
+org.apache.geronimo.st.v30.ui/trace/sections=false
+org.apache.geronimo.st.v30.ui/trace/blueprint=false
+org.apache.geronimo.st.v30.ui/trace/handlers=false
\ No newline at end of file

Modified: geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/Activator.java
URL: http://svn.apache.org/viewvc/geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/Activator.java?rev=1127422&r1=1127421&r2=1127422&view=diff
==============================================================================
--- geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/Activator.java (original)
+++ geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/Activator.java Wed May 25 08:16:27 2011
@@ -23,6 +23,7 @@ import java.util.HashMap;
 
 import org.apache.geronimo.st.v30.ui.internal.Trace;
 import org.eclipse.core.runtime.FileLocator;
+import org.eclipse.core.runtime.Platform;
 import org.eclipse.jface.resource.ImageDescriptor;
 import org.eclipse.jface.resource.ImageRegistry;
 import org.eclipse.swt.graphics.Image;
@@ -38,7 +39,60 @@ public class Activator extends AbstractU
 
     // The plug-in ID
     public static final String PLUGIN_ID = "org.apache.geronimo.st.v30.ui";
-
+	public static boolean console;
+	public static boolean logUi;
+	public static boolean logActions;
+	public static boolean logCommands;
+	public static boolean logInternal;
+	public static boolean logWizards;
+	public static boolean logEditors;
+	public static boolean logPages;
+	public static boolean logSections;
+	public static boolean logBlueprint;
+	public static boolean logHandlers;
+	
+	public static boolean traceUi;
+	public static boolean traceActions;
+	public static boolean traceCommands;
+	public static boolean traceInternal;
+	public static boolean traceWizards;
+	public static boolean traceEditors;
+	public static boolean tracePages;
+	public static boolean traceSections;
+	public static boolean traceBlueprint;
+	public static boolean traceHandlers;
+	
+	static {
+		try {
+			console = Boolean.parseBoolean(Platform.getDebugOption("org.apache.geronimo.st.v11.ui/console"));
+			
+			logUi = Boolean.parseBoolean(Platform.getDebugOption("org.apache.geronimo.st.v11.ui/log/ui"));
+			logActions = Boolean.parseBoolean(Platform.getDebugOption("org.apache.geronimo.st.v11.ui/log/actions"));
+			logCommands = Boolean.parseBoolean(Platform.getDebugOption("org.apache.geronimo.st.v11.ui/log/commands"));
+			logInternal = Boolean.parseBoolean(Platform.getDebugOption("org.apache.geronimo.st.v11.ui/log/internal"));
+			logWizards = Boolean.parseBoolean(Platform.getDebugOption("org.apache.geronimo.st.v11.ui/log/wizards"));
+			logEditors = Boolean.parseBoolean(Platform.getDebugOption("org.apache.geronimo.st.v11.ui/log/editors"));
+			logPages = Boolean.parseBoolean(Platform.getDebugOption("org.apache.geronimo.st.v11.ui/log/pages"));
+			logSections = Boolean.parseBoolean(Platform.getDebugOption("org.apache.geronimo.st.v11.ui/log/sections"));
+			logBlueprint = Boolean.parseBoolean(Platform.getDebugOption("org.apache.geronimo.st.v11.ui/log/blueprint"));
+			logHandlers = Boolean.parseBoolean(Platform.getDebugOption("org.apache.geronimo.st.v11.ui/log/handlers"));
+			
+			traceUi = Boolean.parseBoolean(Platform.getDebugOption("org.apache.geronimo.st.v11.ui/trace/ui"));
+			traceActions = Boolean.parseBoolean(Platform.getDebugOption("org.apache.geronimo.st.v11.ui/trace/actions"));
+			traceCommands = Boolean.parseBoolean(Platform.getDebugOption("org.apache.geronimo.st.v11.ui/trace/commands"));
+			traceInternal = Boolean.parseBoolean(Platform.getDebugOption("org.apache.geronimo.st.v11.ui/trace/internal"));
+			traceWizards = Boolean.parseBoolean(Platform.getDebugOption("org.apache.geronimo.st.v11.ui/trace/wizards"));
+			traceEditors = Boolean.parseBoolean(Platform.getDebugOption("org.apache.geronimo.st.v11.ui/trace/editors"));
+			tracePages = Boolean.parseBoolean(Platform.getDebugOption("org.apache.geronimo.st.v11.ui/trace/pages"));
+			traceSections = Boolean.parseBoolean(Platform.getDebugOption("org.apache.geronimo.st.v11.ui/trace/sections"));
+			traceBlueprint = Boolean.parseBoolean(Platform.getDebugOption("org.apache.geronimo.st.v11.ui/trace/blueprint"));
+			traceHandlers = Boolean.parseBoolean(Platform.getDebugOption("org.apache.geronimo.st.v11.ui/trace/handlers"));
+		} catch(NumberFormatException e) {
+    		Trace.trace(Trace.ERROR, e.getMessage(), true);
+    	} catch(NullPointerException e) {
+    		Trace.trace(Trace.ERROR, e.getMessage(), true);
+    	}
+	}
     // The shared instance
     private static Activator plugin;
 
@@ -140,7 +194,7 @@ public class Activator extends AbstractU
             registry.put(key, id);
             imageDescriptors.put(key, id);
         } catch (Exception e) {
-            Trace.trace(Trace.WARNING, "Error registering image", e);
+            Trace.trace(Trace.WARNING, "Error registering image", e, Activator.logUi);
         }
     }
 

Modified: geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/actions/LaunchGeronimoConsoleAction.java
URL: http://svn.apache.org/viewvc/geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/actions/LaunchGeronimoConsoleAction.java?rev=1127422&r1=1127421&r2=1127422&view=diff
==============================================================================
--- geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/actions/LaunchGeronimoConsoleAction.java (original)
+++ geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/actions/LaunchGeronimoConsoleAction.java Wed May 25 08:16:27 2011
@@ -19,6 +19,7 @@ package org.apache.geronimo.st.v30.ui.ac
 import java.net.MalformedURLException;
 import java.net.URL;
 
+import org.apache.geronimo.st.ui.Activator;
 import org.apache.geronimo.st.v30.core.GeronimoServerDelegate;
 import org.apache.geronimo.st.v30.ui.internal.Messages;
 import org.apache.geronimo.st.v30.ui.internal.Trace;
@@ -51,12 +52,12 @@ public class LaunchGeronimoConsoleAction
                 .getConfigurationElementsFor("org.apache.geronimo.st.v30.ui.actionURLs");
         for (IConfigurationElement element : extensions) {
             Trace.trace(Trace.INFO, element.getName() + " = "
-                    + element.getValue() + ".");
+                    + element.getValue() + ".", Activator.traceActions);
             if (element.getName().equals("server_prefix")) {
                 serverPrefix = element.getValue();
                 Trace
                         .trace(Trace.INFO, "server_prefix = " + serverPrefix
-                                + ".");
+                                + ".", Activator.traceActions);
             }
         }
     }

Modified: geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/actions/LaunchGeronimoSupportAction.java
URL: http://svn.apache.org/viewvc/geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/actions/LaunchGeronimoSupportAction.java?rev=1127422&r1=1127421&r2=1127422&view=diff
==============================================================================
--- geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/actions/LaunchGeronimoSupportAction.java (original)
+++ geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/actions/LaunchGeronimoSupportAction.java Wed May 25 08:16:27 2011
@@ -19,6 +19,7 @@ package org.apache.geronimo.st.v30.ui.ac
 import java.net.MalformedURLException;
 import java.net.URL;
 
+import org.apache.geronimo.st.ui.Activator;
 import org.apache.geronimo.st.v30.ui.internal.Messages;
 import org.apache.geronimo.st.v30.ui.internal.Trace;
 import org.eclipse.core.runtime.IConfigurationElement;
@@ -52,19 +53,19 @@ public class LaunchGeronimoSupportAction
                 .getConfigurationElementsFor("org.apache.geronimo.st.v30.ui.actionURLs");
         for (IConfigurationElement element : extensions) {
             Trace.trace(Trace.INFO, element.getName() + " = "
-                    + element.getValue() + ".");
+                    + element.getValue() + ".", Activator.traceActions);
             if (element.getName().equals("server_prefix")) {
                 serverPrefix = element.getValue();
                 Trace
                         .trace(Trace.INFO, "server_prefix = " + serverPrefix
-                                + ".");
+                                + ".", Activator.traceActions);
             } else if (element.getName().equals("action_URL")
                     && element
                             .getAttribute("class")
                             .equals(
                                     "org.apache.geronimo.st.v30.ui.actions.LaunchGeronimoSupportAction")) {
                 supportURL = element.getAttribute("URL");
-                Trace.trace(Trace.INFO, "support URL = " + supportURL + ".");
+                Trace.trace(Trace.INFO, "support URL = " + supportURL + ".", Activator.traceActions);
             }
         }
     }

Modified: geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/commands/SetClasspathContainersCommand.java
URL: http://svn.apache.org/viewvc/geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/commands/SetClasspathContainersCommand.java?rev=1127422&r1=1127421&r2=1127422&view=diff
==============================================================================
--- geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/commands/SetClasspathContainersCommand.java (original)
+++ geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/commands/SetClasspathContainersCommand.java Wed May 25 08:16:27 2011
@@ -18,6 +18,8 @@ package org.apache.geronimo.st.v30.ui.co
 
 import java.util.ArrayList;
 import java.util.List;
+
+import org.apache.geronimo.st.ui.Activator;
 import org.apache.geronimo.st.v30.core.GeronimoServerDelegate;
 import org.apache.geronimo.st.v30.ui.internal.Trace;
 import org.eclipse.wst.server.core.IServerWorkingCopy;
@@ -40,8 +42,8 @@ public class SetClasspathContainersComma
         super(server, "SetClasspathContainersCommand");
         this.newList = createList( checkList );
 
-        Trace.tracePoint("ENTRY", "SetClasspathContainersCommand", checkList, checkList.length );
-        Trace.tracePoint("EXIT", "SetClasspathContainersCommand");
+        Trace.tracePoint("ENTRY", Activator.traceCommands, "SetClasspathContainersCommand", checkList, checkList.length );
+        Trace.tracePoint("EXIT", Activator.traceCommands, "SetClasspathContainersCommand");
     }
 
 
@@ -51,13 +53,13 @@ public class SetClasspathContainersComma
      * @see org.apache.geronimo.st.v30.ui.commands.ServerCommand#execute()
      */
     public void execute() {
-        Trace.tracePoint("ENTRY", "SetClasspathContainersCommand.execute");
+        Trace.tracePoint("ENTRY", Activator.traceCommands, "SetClasspathContainersCommand.execute");
 
         GeronimoServerDelegate gs = (GeronimoServerDelegate) server.getAdapter(GeronimoServerDelegate.class);
         oldList = gs.getClasspathContainers();
         gs.setClasspathContainers(newList);
 
-        Trace.tracePoint("EXIT", "SetClasspathContainersCommand.execute");
+        Trace.tracePoint("EXIT", Activator.traceCommands, "SetClasspathContainersCommand.execute");
     }
 
 
@@ -67,12 +69,12 @@ public class SetClasspathContainersComma
      * @see org.apache.geronimo.st.v30.ui.commands.ServerCommand#undo()
      */
     public void undo() {
-        Trace.tracePoint("ENTRY", "SetClasspathContainersCommand.undo");
+        Trace.tracePoint("ENTRY", Activator.traceCommands, "SetClasspathContainersCommand.undo");
 
         GeronimoServerDelegate gs = (GeronimoServerDelegate) server.getAdapter(GeronimoServerDelegate.class);
         gs.setClasspathContainers(oldList);
 
-        Trace.tracePoint("EXIT", "SetClasspathContainersCommand.undo");
+        Trace.tracePoint("EXIT", Activator.traceCommands, "SetClasspathContainersCommand.undo");
     }
 
 
@@ -80,14 +82,14 @@ public class SetClasspathContainersComma
     // Convert object array to List<String>
     //
     public List<String> createList( Object[] checkList ) {
-        Trace.tracePoint("ENTRY", "SetClasspathContainersCommand.createList");
+        Trace.tracePoint("ENTRY", Activator.traceCommands, "SetClasspathContainersCommand.createList");
     
         List<String> containers = new ArrayList<String>();
         for (Object container : checkList) {
             containers.add( (String)container );
         }
 
-        Trace.tracePoint("EXIT", "SetClasspathContainersCommand.createList", containers );
+        Trace.tracePoint("EXIT", Activator.traceCommands, "SetClasspathContainersCommand.createList", containers );
         return containers;
    }
 

Modified: geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/handlers/DownloadGeronimo.java
URL: http://svn.apache.org/viewvc/geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/handlers/DownloadGeronimo.java?rev=1127422&r1=1127421&r2=1127422&view=diff
==============================================================================
--- geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/handlers/DownloadGeronimo.java (original)
+++ geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/handlers/DownloadGeronimo.java Wed May 25 08:16:27 2011
@@ -19,6 +19,7 @@ package org.apache.geronimo.st.v30.ui.ha
 import java.net.MalformedURLException;
 import java.net.URL;
 
+import org.apache.geronimo.st.v30.ui.Activator;
 import org.apache.geronimo.st.v30.ui.internal.Messages;
 import org.apache.geronimo.st.v30.ui.internal.Trace;
 import org.eclipse.core.commands.AbstractHandler;
@@ -41,7 +42,7 @@ import org.eclipse.ui.internal.browser.W
 public class DownloadGeronimo extends AbstractHandler {
 
     public Object execute(ExecutionEvent event) throws ExecutionException {
-        Trace.tracePoint("Entry", "DownloadGeronimo.execute", event);
+        Trace.tracePoint("Entry", Activator.traceHandlers, "DownloadGeronimo.execute", event);
 
         String url = Messages.DownloadServerURL;
 
@@ -57,7 +58,7 @@ public class DownloadGeronimo extends Ab
             e.printStackTrace();
         }
 
-        Trace.tracePoint("Exit", "DownloadGeronimo.execute");
+        Trace.tracePoint("Exit", Activator.traceHandlers, "DownloadGeronimo.execute");
         return null;
     }
 }

Modified: geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/handlers/DownloadOSGi.java
URL: http://svn.apache.org/viewvc/geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/handlers/DownloadOSGi.java?rev=1127422&r1=1127421&r2=1127422&view=diff
==============================================================================
--- geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/handlers/DownloadOSGi.java (original)
+++ geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/handlers/DownloadOSGi.java Wed May 25 08:16:27 2011
@@ -19,6 +19,7 @@ package org.apache.geronimo.st.v30.ui.ha
 import java.net.MalformedURLException;
 import java.net.URL;
 
+import org.apache.geronimo.st.v30.ui.Activator;
 import org.apache.geronimo.st.v30.ui.internal.Messages;
 import org.apache.geronimo.st.v30.ui.internal.Trace;
 import org.eclipse.core.commands.AbstractHandler;
@@ -40,7 +41,7 @@ import org.eclipse.ui.internal.browser.W
 public class DownloadOSGi extends AbstractHandler  {
 
     public Object execute(ExecutionEvent event) throws ExecutionException {
-        Trace.tracePoint("Entry", "DownloadOSGi.execute", event);
+        Trace.tracePoint("Entry", Activator.traceHandlers, "DownloadOSGi.execute", event);
 
         String url = Messages.DownloadOSGiURL;
 
@@ -56,7 +57,7 @@ public class DownloadOSGi extends Abstra
             e.printStackTrace();
         }
 
-        Trace.tracePoint("Exit", "DownloadOSGi.execute");
+        Trace.tracePoint("Exit", Activator.traceHandlers, "DownloadOSGi.execute");
         return null;
     }
 

Modified: geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/internal/GeronimoRuntimeWizardFragment.java
URL: http://svn.apache.org/viewvc/geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/internal/GeronimoRuntimeWizardFragment.java?rev=1127422&r1=1127421&r2=1127422&view=diff
==============================================================================
--- geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/internal/GeronimoRuntimeWizardFragment.java (original)
+++ geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/internal/GeronimoRuntimeWizardFragment.java Wed May 25 08:16:27 2011
@@ -194,7 +194,7 @@ public class GeronimoRuntimeWizardFragme
             @Override
             public void linkActivated(HyperlinkEvent hyperlinkEvent) {
                 String url = hyperlinkEvent.getHref().toString();
-                Trace.trace(Trace.INFO, "Hyperlink " + url + ".");
+                Trace.trace(Trace.INFO, "Hyperlink " + url + ".", Activator.traceInternal);
                 try {
                     int style = IWorkbenchBrowserSupport.AS_EXTERNAL
                             | IWorkbenchBrowserSupport.STATUS;

Modified: geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/internal/Trace.java
URL: http://svn.apache.org/viewvc/geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/internal/Trace.java?rev=1127422&r1=1127421&r2=1127422&view=diff
==============================================================================
--- geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/sections/ServerEditorSecuritySection.java (original)
+++ geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/sections/ServerEditorSecuritySection.java Wed May 25 08:16:27 2011
@@ -17,6 +17,7 @@
 package org.apache.geronimo.st.v30.ui.sections;
 
 import org.apache.geronimo.st.v30.core.operations.GeronimoAccountManager;
+import org.apache.geronimo.st.v30.ui.Activator;
 import org.apache.geronimo.st.v30.ui.CommonMessages;
 import org.apache.geronimo.st.v30.ui.commands.SetPasswordCommand;
 import org.apache.geronimo.st.v30.ui.commands.SetUsernameCommand;
@@ -103,7 +104,7 @@ public class ServerEditorSecuritySection
                         manager.init();
                     } catch (Exception e1) {
                         MessageDialog.openError(Display.getCurrent().getActiveShell(), CommonMessages.errorOpenWizard, CommonMessages.cannotRead);
-                        Trace.trace(Trace.SEVERE, "Properties file containing user information can't be read!", e1);
+                        Trace.trace(Trace.ERROR, "Properties file containing user information can't be read!", e1, Activator.logSections);
                         return;
                     }
                     ManageAccountWizard wizard = new ManageAccountWizard(manager);

Modified: geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/sections/ServerEditorTestEnvSection.java
URL: http://svn.apache.org/viewvc/geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/sections/ServerEditorTestEnvSection.java?rev=1127422&r1=1127421&r2=1127422&view=diff
==============================================================================
--- geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/sections/ServerEditorTestEnvSection.java (original)
+++ geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/sections/ServerEditorTestEnvSection.java Wed May 25 08:16:27 2011
@@ -19,6 +19,7 @@ package org.apache.geronimo.st.v30.ui.se
 import java.util.List;
 
 import org.apache.geronimo.st.v30.core.ClasspathContainersHelper;
+import org.apache.geronimo.st.v30.ui.Activator;
 import org.apache.geronimo.st.v30.ui.commands.SetClasspathContainersCommand;
 import org.apache.geronimo.st.v30.ui.commands.SetInPlaceSharedLibCommand;
 import org.apache.geronimo.st.v30.ui.commands.SetNotRedeployJSPFilesCommand;
@@ -72,7 +73,7 @@ public class ServerEditorTestEnvSection 
     public void createSection(Composite parent) {
         super.createSection(parent);
 
-        Trace.tracePoint("ENTRY", "ServerEditorTestEnvSection.createSection", parent);
+        Trace.tracePoint("ENTRY", Activator.traceSections, "ServerEditorTestEnvSection.createSection", parent);
 
         toolkit = getFormToolkit(parent.getDisplay());
 
@@ -213,14 +214,14 @@ public class ServerEditorTestEnvSection 
             checkbox.getTable().setEnabled( false );
         }
 
-        Trace.tracePoint("EXIT", "ServerEditorTestEnvSection.createSection");
+        Trace.tracePoint("EXIT", Activator.traceSections, "ServerEditorTestEnvSection.createSection");
     }
 
     //
     // CheckboxTableViewer: checkbox
     //
     public void createCheckbox() {
-        Trace.tracePoint("ENTRY", "ServerEditorTestEnvSection.createCheckbox");
+        Trace.tracePoint("ENTRY", Activator.traceSections, "ServerEditorTestEnvSection.createCheckbox");
     
         if ( checkbox == null ) {
                     
@@ -245,6 +246,6 @@ public class ServerEditorTestEnvSection 
             });
         }
 
-        Trace.tracePoint("EXIT", "ServerEditorTestEnvSection.createCheckbox");
+        Trace.tracePoint("EXIT", Activator.traceSections, "ServerEditorTestEnvSection.createCheckbox");
     }
 }

Modified: geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/sections/ServerPluginSection.java
URL: http://svn.apache.org/viewvc/geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/sections/ServerPluginSection.java?rev=1127422&r1=1127421&r2=1127422&view=diff
==============================================================================
--- geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/sections/ServerPluginSection.java (original)
+++ geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/sections/ServerPluginSection.java Wed May 25 08:16:27 2011
@@ -17,6 +17,7 @@
 package org.apache.geronimo.st.v30.ui.sections;
 
 import org.apache.geronimo.st.v30.core.operations.GeronimoServerPluginManager;
+import org.apache.geronimo.st.v30.ui.Activator;
 import org.apache.geronimo.st.v30.ui.CommonMessages;
 import org.apache.geronimo.st.v30.ui.internal.Trace;
 import org.apache.geronimo.st.v30.ui.wizards.ServerCustomAssemblyWizard;
@@ -56,7 +57,7 @@ public class ServerPluginSection extends
     public void createSection(Composite parent) {
         super.createSection(parent);
     
-        Trace.tracePoint("Entry", "ServerPluginSection.createSection", parent);
+        Trace.tracePoint("Entry", Activator.traceSections, "ServerPluginSection.createSection", parent);
     
         FormToolkit toolkit = getFormToolkit(parent.getDisplay());
         
@@ -121,7 +122,7 @@ public class ServerPluginSection extends
             }
         });
     
-        Trace.tracePoint("Exit", "ServerPluginSection.createSection");
+        Trace.tracePoint("Exit", Activator.traceSections, "ServerPluginSection.createSection");
     }
 
     private boolean isServerRunning () {

Modified: geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/sections/blueprint/AbstractBlueprintTreeSectionPart.java
URL: http://svn.apache.org/viewvc/geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/sections/blueprint/AbstractBlueprintTreeSectionPart.java?rev=1127422&r1=1127421&r2=1127422&view=diff
==============================================================================
--- geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/sections/blueprint/AbstractBlueprintTreeSectionPart.java (original)
+++ geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/sections/blueprint/AbstractBlueprintTreeSectionPart.java Wed May 25 08:16:27 2011
@@ -62,15 +62,15 @@ public abstract class AbstractBlueprintT
         try {
             BlueprintJAXBHelper.setAttributeValue(selectedObject,attrMap);
         } catch (SecurityException e) {
-            Trace.trace(Trace.SEVERE, "can't set attribute value for object "+selectedObject, e);
+            Trace.trace(Trace.ERROR, "can't set attribute value for object "+selectedObject, e, Activator.logBlueprint);
         } catch (IllegalArgumentException e) {
-            Trace.trace(Trace.SEVERE, "can't set attribute value for object "+selectedObject, e);
+            Trace.trace(Trace.ERROR, "can't set attribute value for object "+selectedObject, e, Activator.logBlueprint);
         } catch (NoSuchMethodException e) {
-            Trace.trace(Trace.SEVERE, "can't set attribute value for object "+selectedObject, e);
+            Trace.trace(Trace.ERROR, "can't set attribute value for object "+selectedObject, e, Activator.logBlueprint);
         } catch (IllegalAccessException e) {
-            Trace.trace(Trace.SEVERE, "can't set attribute value for object "+selectedObject, e);
+            Trace.trace(Trace.ERROR, "can't set attribute value for object "+selectedObject, e, Activator.logBlueprint);
         } catch (InvocationTargetException e) {
-            Trace.trace(Trace.SEVERE, "can't set attribute value for object "+selectedObject, e);
+            Trace.trace(Trace.ERROR, "can't set attribute value for object "+selectedObject, e, Activator.logBlueprint);
         }
         
     }
@@ -81,30 +81,30 @@ public abstract class AbstractBlueprintT
          try {
             BlueprintJAXBHelper.setAttributeValue(newObject,attrMap);
         } catch (SecurityException e) {
-            Trace.trace(Trace.SEVERE, "can't set attribute value for object "+newObject, e);
+            Trace.trace(Trace.ERROR, "can't set attribute value for object "+newObject, e, Activator.logBlueprint);
         } catch (IllegalArgumentException e) {
-            Trace.trace(Trace.SEVERE, "can't set attribute value for object "+newObject, e);
+            Trace.trace(Trace.ERROR, "can't set attribute value for object "+newObject, e, Activator.logBlueprint);
         } catch (NoSuchMethodException e) {
-            Trace.trace(Trace.SEVERE, "can't set attribute value for object "+newObject, e);
+            Trace.trace(Trace.ERROR, "can't set attribute value for object "+newObject, e, Activator.logBlueprint);
         } catch (IllegalAccessException e) {
-            Trace.trace(Trace.SEVERE, "can't set attribute value for object "+newObject, e);
+            Trace.trace(Trace.ERROR, "can't set attribute value for object "+newObject, e, Activator.logBlueprint);
         } catch (InvocationTargetException e) {
-            Trace.trace(Trace.SEVERE, "can't set attribute value for object "+newObject, e);
+            Trace.trace(Trace.ERROR, "can't set attribute value for object "+newObject, e, Activator.logBlueprint);
         }
          try {
             BlueprintJAXBHelper.attachToParent(parentObject,newObject,clazzWrapper.getField());
         } catch (SecurityException e) {
-            Trace.trace(Trace.SEVERE, "can't add new object "+newObject, e);
+            Trace.trace(Trace.ERROR, "can't add new object "+newObject, e, Activator.logBlueprint);
         } catch (IllegalArgumentException e) {
-            Trace.trace(Trace.SEVERE, "can't add new object "+newObject, e);
+            Trace.trace(Trace.ERROR, "can't add new object "+newObject, e, Activator.logBlueprint);
         } catch (NoSuchFieldException e) {
-            Trace.trace(Trace.SEVERE, "can't add new object "+newObject, e);
+            Trace.trace(Trace.ERROR, "can't add new object "+newObject, e, Activator.logBlueprint);
         } catch (NoSuchMethodException e) {
-            Trace.trace(Trace.SEVERE, "can't add new object "+newObject, e);
+            Trace.trace(Trace.ERROR, "can't add new object "+newObject, e, Activator.logBlueprint);
         } catch (IllegalAccessException e) {
-            Trace.trace(Trace.SEVERE, "can't add new object "+newObject, e);
+            Trace.trace(Trace.ERROR, "can't add new object "+newObject, e, Activator.logBlueprint);
         } catch (InvocationTargetException e) {
-            Trace.trace(Trace.SEVERE, "can't add new object "+newObject, e);
+            Trace.trace(Trace.ERROR, "can't add new object "+newObject, e, Activator.logBlueprint);
         }
         
         treeFieldMap.put(newObject, clazzWrapper.getField());
@@ -140,15 +140,15 @@ public abstract class AbstractBlueprintT
                         List allSubElements = BlueprintJAXBHelper.getAllSubElements(parentElement);
                         return allSubElements.toArray(new Object[0]);
                     } catch (SecurityException e) {
-                        Trace.trace(Trace.SEVERE, "get child elements error! ", e);
+                        Trace.trace(Trace.ERROR, "get child elements error! ", e, Activator.logBlueprint);
                     } catch (IllegalArgumentException e) {
-                        Trace.trace(Trace.SEVERE, "get child elements error! ", e);
+                        Trace.trace(Trace.ERROR, "get child elements error! ", e, Activator.logBlueprint);
                     } catch (NoSuchMethodException e) {
-                        Trace.trace(Trace.SEVERE, "get child elements error! ", e);
+                        Trace.trace(Trace.ERROR, "get child elements error! ", e, Activator.logBlueprint);
                     } catch (IllegalAccessException e) {
-                        Trace.trace(Trace.SEVERE, "get child elements error! ", e);
+                        Trace.trace(Trace.ERROR, "get child elements error! ", e, Activator.logBlueprint);
                     } catch (InvocationTargetException e) {
-                        Trace.trace(Trace.SEVERE, "get child elements error! ", e);
+                        Trace.trace(Trace.ERROR, "get child elements error! ", e, Activator.logBlueprint);
                     }
                     
                 }
@@ -190,15 +190,15 @@ public abstract class AbstractBlueprintT
                         }
                         
                     } catch (SecurityException e) {
-                        Trace.trace(Trace.SEVERE, "get child elements error! ", e);
+                        Trace.trace(Trace.ERROR, "get child elements error! ", e, Activator.logBlueprint);
                     } catch (IllegalArgumentException e) {
-                        Trace.trace(Trace.SEVERE, "get child elements error! ", e);
+                        Trace.trace(Trace.ERROR, "get child elements error! ", e, Activator.logBlueprint);
                     } catch (NoSuchMethodException e) {
-                        Trace.trace(Trace.SEVERE, "get child elements error! ", e);
+                        Trace.trace(Trace.ERROR, "get child elements error! ", e, Activator.logBlueprint);
                     } catch (IllegalAccessException e) {
-                        Trace.trace(Trace.SEVERE, "get child elements error! ", e);
+                        Trace.trace(Trace.ERROR, "get child elements error! ", e, Activator.logBlueprint);
                     } catch (InvocationTargetException e) {
-                        Trace.trace(Trace.SEVERE, "get child elements error! ", e);
+                        Trace.trace(Trace.ERROR, "get child elements error! ", e, Activator.logBlueprint);
                     }
                     
 

Modified: geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/sections/blueprint/OtherElementsSection.java
URL: http://svn.apache.org/viewvc/geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/sections/blueprint/OtherElementsSection.java?rev=1127422&r1=1127421&r2=1127422&view=diff
==============================================================================
--- geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/sections/blueprint/OtherElementsSection.java (original)
+++ geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/sections/blueprint/OtherElementsSection.java Wed May 25 08:16:27 2011
@@ -15,6 +15,7 @@ import org.apache.geronimo.osgi.blueprin
 import org.apache.geronimo.osgi.blueprint.Tservice;
 import org.apache.geronimo.st.ui.internal.Trace;
 import org.apache.geronimo.st.v30.core.jaxb.BlueprintJAXBHelper;
+import org.apache.geronimo.st.v30.ui.Activator;
 import org.apache.geronimo.st.v30.ui.CommonMessages;
 import org.apache.geronimo.st.v30.ui.wizards.blueprint.BlueprintElementWizardProxy;
 import org.eclipse.jface.wizard.Wizard;
@@ -117,11 +118,11 @@ public class OtherElementsSection extend
             try {
                 BlueprintJAXBHelper.detachFromParent(object, anItem, field);
             } catch (IllegalArgumentException e) {
-                Trace.trace(Trace.SEVERE, "can't remove object "+ anItem, e);
+                Trace.trace(Trace.ERROR, "can't remove object "+ anItem, e, Activator.logBlueprint);
             } catch (IllegalAccessException e) {
-                Trace.trace(Trace.SEVERE, "can't remove object "+ anItem, e);
+                Trace.trace(Trace.ERROR, "can't remove object "+ anItem, e, Activator.logBlueprint);
             } catch (InvocationTargetException e) {
-                Trace.trace(Trace.SEVERE, "can't remove object "+ anItem, e);
+                Trace.trace(Trace.ERROR, "can't remove object "+ anItem, e, Activator.logBlueprint);
             }
         } 
     }
@@ -149,9 +150,9 @@ public class OtherElementsSection extend
                 excludedList.add(getBlueprint().getClass().getDeclaredField("description"));
                 excludedList.add(getBlueprint().getClass().getDeclaredField("typeConverters"));
             } catch (SecurityException e) {
-                Trace.trace(Trace.SEVERE, "Can't find field! ", e);
+                Trace.trace(Trace.ERROR, "Can't find field! ", e, Activator.logBlueprint);
             } catch (NoSuchFieldException e) {
-                Trace.trace(Trace.SEVERE, "Can't find field! ", e);
+                Trace.trace(Trace.ERROR, "Can't find field! ", e, Activator.logBlueprint);
             }
             return excludedList;
         }

Modified: geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/wizards/blueprint/BlueprintElementWizardProxy.java
URL: http://svn.apache.org/viewvc/geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/wizards/blueprint/BlueprintElementWizardProxy.java?rev=1127422&r1=1127421&r2=1127422&view=diff
==============================================================================
--- geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/wizards/blueprint/BlueprintElementWizardProxy.java (original)
+++ geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/wizards/blueprint/BlueprintElementWizardProxy.java Wed May 25 08:16:27 2011
@@ -11,6 +11,7 @@ import java.util.List;
 import javax.xml.bind.annotation.XmlAttribute;
 import javax.xml.bind.annotation.XmlRootElement;
 
+import org.apache.geronimo.st.v30.ui.Activator;
 import org.apache.geronimo.st.v30.ui.internal.Messages;
 import org.apache.geronimo.st.ui.internal.Trace;
 import org.apache.geronimo.st.v30.core.jaxb.BlueprintJAXBHelper;
@@ -82,15 +83,15 @@ public class BlueprintElementWizardProxy
                             count++;
                         }
                     } catch (SecurityException e) {
-                        Trace.trace(Trace.SEVERE, "get child elements error! ", e);
+                        Trace.trace(Trace.ERROR, "get child elements error! ", e, Activator.logWizards);
                     } catch (IllegalArgumentException e) {
-                        Trace.trace(Trace.SEVERE, "get child elements error! ", e);
+                        Trace.trace(Trace.ERROR, "get child elements error! ", e, Activator.logWizards);
                     } catch (NoSuchMethodException e) {
-                        Trace.trace(Trace.SEVERE, "get child elements error! ", e);
+                        Trace.trace(Trace.ERROR, "get child elements error! ", e, Activator.logWizards);
                     } catch (IllegalAccessException e) {
-                        Trace.trace(Trace.SEVERE, "get child elements error! ", e);
+                        Trace.trace(Trace.ERROR, "get child elements error! ", e, Activator.logWizards);
                     } catch (InvocationTargetException e) {
-                        Trace.trace(Trace.SEVERE, "get child elements error! ", e);
+                        Trace.trace(Trace.ERROR, "get child elements error! ", e, Activator.logWizards);
                     }
                     
                 }else{

Modified: geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/wizards/facets/GeronimoJEEFacetInstallWizardPage.java
URL: http://svn.apache.org/viewvc/geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/wizards/facets/GeronimoJEEFacetInstallWizardPage.java?rev=1127422&r1=1127421&r2=1127422&view=diff
==============================================================================
--- geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/wizards/facets/GeronimoJEEFacetInstallWizardPage.java (original)
+++ geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/wizards/facets/GeronimoJEEFacetInstallWizardPage.java Wed May 25 08:16:27 2011
@@ -18,6 +18,7 @@ package org.apache.geronimo.st.v30.ui.wi
 
 import org.apache.geronimo.st.ui.internal.Messages;
 import org.apache.geronimo.st.v30.core.facets.DeploymentPlanInstallConfig;
+import org.apache.geronimo.st.v30.ui.Activator;
 import org.apache.geronimo.st.v30.ui.CommonMessages;
 import org.apache.geronimo.st.v30.ui.internal.Trace;
 import org.eclipse.swt.SWT;
@@ -47,12 +48,12 @@ public class GeronimoJEEFacetInstallWiza
 
     public GeronimoJEEFacetInstallWizardPage() {
         super("geronimo.plan.install");
-        Trace.tracePoint("Constructor Entry", "GeroniomoJEEFacetInstallWizardPage");
+        Trace.tracePoint("Constructor Entry", Activator.logWizards, "GeroniomoJEEFacetInstallWizardPage");
         
         setTitle(Messages.geronimoDeploymentPlan);
         setDescription(Messages.configGeronimoDeploymentPlan);
         
-        Trace.tracePoint("Constructor Exit", "GeronimoJEEFacetInstallWizardPage");
+        Trace.tracePoint("Constructor Exit", Activator.logWizards, "GeronimoJEEFacetInstallWizardPage");
     }
 
     /*
@@ -61,11 +62,11 @@ public class GeronimoJEEFacetInstallWiza
      * @see org.eclipse.wst.common.project.facet.ui.IFacetWizardPage#setConfig(java.lang.Object)
      */
     public void setConfig(Object config) {
-        Trace.tracePoint("Entry", "GeronimoJEEFacetInstallWizardPage.setConfig", config);
+        Trace.tracePoint("Entry", Activator.logWizards, "GeronimoJEEFacetInstallWizardPage.setConfig", config);
 
         this.config = (DeploymentPlanInstallConfig) config;
         
-        Trace.tracePoint("Exit", "GeronimoJEEFacetInstallWizardPage.setConfig");
+        Trace.tracePoint("Exit", Activator.logWizards, "GeronimoJEEFacetInstallWizardPage.setConfig");
     }
 
     /*
@@ -74,7 +75,7 @@ public class GeronimoJEEFacetInstallWiza
      * @see org.eclipse.jface.dialogs.IDialogPage#createControl(org.eclipse.swt.widgets.Composite)
      */
     public void createControl(Composite parent) {
-        Trace.tracePoint("Entry", "GeronimoJEEFacetInstallWizardPage.createControl", parent);
+        Trace.tracePoint("Entry", Activator.logWizards, "GeronimoJEEFacetInstallWizardPage.createControl", parent);
         
         Composite composite = new Composite(parent, SWT.NONE);
         composite.setLayout(new GridLayout(2, false));
@@ -115,7 +116,7 @@ public class GeronimoJEEFacetInstallWiza
         
         setControl(composite);
         
-        Trace.tracePoint("Exit", "GeronimoJEEFacetInstallWizardPage.createControl");      
+        Trace.tracePoint("Exit", Activator.logWizards, "GeronimoJEEFacetInstallWizardPage.createControl");      
     }
 
     /*
@@ -124,7 +125,7 @@ public class GeronimoJEEFacetInstallWiza
      * @see org.eclipse.wst.common.project.facet.ui.AbstractFacetWizardPage#transferStateToConfig()
      */
     public void transferStateToConfig() {
-        Trace.tracePoint("Entry", "GeronimoJEEFacetInstallWizardPage.transferStateToConfig");     
+        Trace.tracePoint("Entry", Activator.logWizards, "GeronimoJEEFacetInstallWizardPage.transferStateToConfig");     
     
         config.setGroupId(groupText.getText());
         config.setArtifactId(artifactText.getText());
@@ -132,7 +133,7 @@ public class GeronimoJEEFacetInstallWiza
         config.setType(typeText.getText());
         config.setSharedLib(sharedLib.getSelection());
         
-        Trace.tracePoint("Exit", "GeronimoJEEFacetInstallWizardPage.transferStateToConfig");      
+        Trace.tracePoint("Exit", Activator.logWizards, "GeronimoJEEFacetInstallWizardPage.transferStateToConfig");      
     }
 
     private static GridData createGridData() {
--- geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/internal/Trace.java (original)
+++ geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/internal/Trace.java Wed May 25 08:16:27 2011
@@ -16,6 +16,7 @@
  */
 package org.apache.geronimo.st.v30.ui.internal;
 
+import org.apache.geronimo.runtime.common.log.Logger;
 import org.apache.geronimo.st.v30.ui.Activator;
 
 /**
@@ -28,21 +29,29 @@ public class Trace {
     /**
      * Finest trace event.
      */
-    public static byte INFO = 0;
+    public static int INFO = 1;
 
     /**
      * Warning trace event.
      */
-    public static byte WARNING = 1;
+    public static int WARNING = 2;
 
     /**
      * Severe trace event.
      */
-    public static byte SEVERE = 2;
+    public static int ERROR = 4;
+    /**
+     * cancel trace event.
+     */
+    public static int CANCEL = 8;
 
     /**
      * Trace constructor comment.
      */
+    private static Logger log;
+    static {
+    	log = Logger.getInstance();
+    }
     private Trace() {
         super();
     }
@@ -55,8 +64,8 @@ public class Trace {
      * @param s
      *            a message
      */
-    public static void trace(byte level, String s) {
-        trace(level, s, null);
+    public static void trace(int level, String s, boolean opt) {
+        trace(level, s, null, opt);
     }
 
     /**
@@ -69,13 +78,17 @@ public class Trace {
      * @param t
      *            a throwable
      */
-    public static void trace(byte level, String s, Throwable t) {
+    public static void trace(int level, String s, Throwable t, boolean opt) {
         if (Activator.getDefault() == null || !Activator.getDefault().isDebugging())
             return;
-
-        System.out.println(Activator.PLUGIN_ID + ":  " + s);
-        if (t != null)
-            t.printStackTrace();
+        if(opt) {
+        	log.trace(level, Activator.PLUGIN_ID, s, t);
+        }
+        if(Activator.console) {
+            System.out.println(Activator.PLUGIN_ID + ":  " + s);
+            if (t != null)
+                t.printStackTrace();
+        }
     }
 
     /**
@@ -92,20 +105,20 @@ public class Trace {
      *            or
      *            Return value if the trace point is an "Exit"
      */
-    public static void tracePoint(String tracePoint, String classDotMethod) {
-        trace(Trace.INFO, tracePoint + ": " + classDotMethod + "()" );
+    public static void tracePoint(String tracePoint, String classDotMethod, boolean opt) {
+        trace(Trace.INFO, tracePoint + ": " + classDotMethod + "()", opt);
     }   
-    public static void tracePoint(String tracePoint, String classDotMethod, Object... parms) {
+    public static void tracePoint(String tracePoint, boolean opt, String classDotMethod, Object... parms) {
         if ( parms == null ) {
-            trace(Trace.INFO, tracePoint + ": " + classDotMethod + "( null )" );
+            trace(Trace.INFO, tracePoint + ": " + classDotMethod + "( null )" , opt);
         }
         else {
-            trace(Trace.INFO, tracePoint + ": " + classDotMethod + "(" );
+            trace(Trace.INFO, tracePoint + ": " + classDotMethod + "(" , opt);
             for ( int ii=0; ii<parms.length; ii++) {
                 Object parm = parms[ii];
-                trace(Trace.INFO, "    parm" + (ii+1) + "=[" + (parm == null ? null : parm.toString()) + "]" );
+                trace(Trace.INFO, "    parm" + (ii+1) + "=[" + (parm == null ? null : parm.toString()) + "]" , opt);
             }
-            trace(Trace.INFO, ")" );
+            trace(Trace.INFO, ")" ,opt);
         }
-    }   
+    }    
 }
\ No newline at end of file
@@ -28,21 +29,29 @@ public class Trace {
 
     /**
-     * Severe trace event.
+     * error trace event.
      */

Modified: geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/sections/ServerEditorSecuritySection.java
URL: http://svn.apache.org/viewvc/geronimo/devtools/eclipse-plugin/trunk/plugins/org.apache.geronimo.st.v30.ui/src/main/java/org/apache/geronimo/st/v30/ui/sections/ServerEditorSecuritySection.java?rev=1127422&r1=1127421&r2=1127422&view=diff
==============================================================================